@@ -182,6 +182,7 @@ def add_line_in_file(
 
 def del_line_in_file(file_path, old_line_number):
     import fileinput
+
     deleted_line = ""
     line_number = 0
     with fileinput.FileInput(file_path, inplace=True) as f:
@@ -193,8 +194,10 @@ def del_line_in_file(file_path, old_line_number):
                 print(line, end="")
     return deleted_line
 
+
 def del_line_block_in_file(file_path, old_line_number_begin, old_line_number_end):
     import fileinput
+
     deleted_line = ""
     line_number = 0
     with fileinput.FileInput(file_path, inplace=True) as f:
@@ -203,31 +206,48 @@ def del_line_block_in_file(file_path, old_line_number_begin, old_line_number_end
             if old_line_number_begin == line_number:
                 deleted_line = line
             else:
-                if old_line_number_begin < line_number and line_number <= old_line_number_end:
+                if (
+                    old_line_number_begin < line_number
+                    and line_number <= old_line_number_end
+                ):
                     deleted_line = deleted_line + line
                 else:
                     print(line, end="")
     return deleted_line
 
+
 def move_line_in_file(file_path, old_line_number, new_line_number):
-    if (old_line_number <= new_line_number and new_line_number <= (old_line_number + 1)):
+    if old_line_number <= new_line_number and new_line_number <= (old_line_number + 1):
         return ""
     else:
         new_line_content = del_line_in_file(file_path, old_line_number)
-        if (old_line_number > new_line_number):
-            add_line_in_file(file_path, new_line_number, new_line_content)
+        if old_line_number > new_line_number:
+            add_line_in_file(file_path, new_line_number, new_line_content, "")
         else:
-            add_line_in_file(file_path, new_line_number - 1, new_line_content)
+            add_line_in_file(file_path, new_line_number - 1, new_line_content, "")
 
-def move_line_block_in_file(file_path, old_line_number_begin, old_line_number_end, new_line_number):
-    if (old_line_number_begin <= new_line_number and new_line_number <= (old_line_number_end + 1)):
+
+def move_line_block_in_file(
+    file_path, old_line_number_begin, old_line_number_end, new_line_number
+):
+    if old_line_number_begin <= new_line_number and new_line_number <= (
+        old_line_number_end + 1
+    ):
         return
     else:
-        new_line_content = del_line_block_in_file(file_path, old_line_number_begin, old_line_number_end)
-        if (old_line_number_begin > new_line_number):
-            add_line_in_file(file_path, new_line_number, new_line_content)
+        new_line_content = del_line_block_in_file(
+            file_path, old_line_number_begin, old_line_number_end
+        )
+        if old_line_number_begin > new_line_number:
+            add_line_in_file(file_path, new_line_number, new_line_content, "")
         else:
-            add_line_in_file(file_path, new_line_number - (old_line_number_end - old_line_number_begin + 1), new_line_content)
+            add_line_in_file(
+                file_path,
+                new_line_number - (old_line_number_end - old_line_number_begin + 1),
+                new_line_content,
+                "",
+            )
+
 
 def read_text_file(file_path):
     from pathlib import Path
@@ -291,53 +311,70 @@ def del_block_in_file(file_path, block_line_begin, block_line_end):
             else:
                 print(line, end="")
 
+
 def full_page_snapshot(url, dir_snapshot):
     from selenium import webdriver
-    from selenium.webdriver.common.by import By;
+    from selenium.webdriver.common.by import By
     import time
     import os
-    assert(os.path.isdir(dir_snapshot))
-    if 'http_proxy' in os.environ:
-        del os.environ['http_proxy']
+
+    assert os.path.isdir(dir_snapshot)
+    if "http_proxy" in os.environ:
+        del os.environ["http_proxy"]
     chrome_options = webdriver.ChromeOptions()
     driver = webdriver.Remote(
-        command_executor='http://127.0.0.1:4444/wd/hub',
-        options=chrome_options)
+        command_executor="http://127.0.0.1:4444/wd/hub", options=chrome_options
+    )
     driver.maximize_window()
     driver.get(url=url)
     # Wait some time for page loading
     time.sleep(4)
     found_page_source = driver.page_source
     try:
-        span_collapse = driver.find_element(by=By.XPATH, value = "//span[text()=\"«\"]")
+        span_collapse = driver.find_element(by=By.XPATH, value='//span[text()="«"]')
         span_collapse.click()
     except Exception as e:
         print(e)
     driver.save_screenshot(dir_snapshot + os.path.sep + "screenshot.png")
-    
+
     main_scroll_height = 0
     main_scroll_top = 0
     page_height = 0
     flag_main_element = False
     try:
-        main_scroll_height = driver.execute_script("return document.getElementById('MAIN').scrollHeight")
-        main_scroll_top = driver.execute_script("return document.getElementById('MAIN').scrollTop")    
+        main_scroll_height = driver.execute_script(
+            "return document.getElementById('MAIN').scrollHeight"
+        )
+        main_scroll_top = driver.execute_script(
+            "return document.getElementById('MAIN').scrollTop"
+        )
         page_height = driver.execute_script("return document.body.scrollHeight")
         flag_main_element = True
     except Exception as e:
         print(e)
-        main_scroll_height = driver.execute_script('return document.body.parentNode.scrollHeight')
-        main_scroll_top = driver.execute_script('return document.body.parentNode.scrollTop')
-        page_height = driver.execute_script('return window.innerHeight')
-    
-    print("main_scroll_height is %d main_scroll_top is %d page_height is %d" % (main_scroll_height, main_scroll_top, page_height))
+        main_scroll_height = driver.execute_script(
+            "return document.body.parentNode.scrollHeight"
+        )
+        main_scroll_top = driver.execute_script(
+            "return document.body.parentNode.scrollTop"
+        )
+        page_height = driver.execute_script("return window.innerHeight")
+
+    print(
+        "main_scroll_height is %d main_scroll_top is %d page_height is %d"
+        % (main_scroll_height, main_scroll_top, page_height)
+    )
     while True:
         driver.execute_script("window.scrollBy(0, %d);" % page_height)
         time.sleep(1)
         if flag_main_element:
-            new_main_scroll_height = driver.execute_script("return document.getElementById('MAIN').scrollHeight")
+            new_main_scroll_height = driver.execute_script(
+                "return document.getElementById('MAIN').scrollHeight"
+            )
         else:
-            new_main_scroll_height = driver.execute_script('return document.body.parentNode.scrollHeight')
+            new_main_scroll_height = driver.execute_script(
+                "return document.body.parentNode.scrollHeight"
+            )
         if new_main_scroll_height == main_scroll_height:
             break
         main_scroll_height = new_main_scroll_height
@@ -345,25 +382,39 @@ def full_page_snapshot(url, dir_snapshot):
 
     driver.execute_script("window.scrollTo(0, 0);")
     page_index = 1
-    driver.save_screenshot(dir_snapshot + os.path.sep + ("page_%06d.png"%page_index))
-    
+    driver.save_screenshot(dir_snapshot + os.path.sep + ("page_%06d.png" % page_index))
+
     if flag_main_element:
-        main_scroll_height = driver.execute_script("return document.getElementById('MAIN').scrollHeight")
+        main_scroll_height = driver.execute_script(
+            "return document.getElementById('MAIN').scrollHeight"
+        )
         page_height = driver.execute_script("return document.body.scrollHeight")
     else:
-        main_scroll_height = driver.execute_script("return document.documentElement.scrollHeight")
-        page_height = driver.execute_script('return window.innerHeight')
-    
+        main_scroll_height = driver.execute_script(
+            "return document.documentElement.scrollHeight"
+        )
+        page_height = driver.execute_script("return window.innerHeight")
+
     window_page_y_offset = driver.execute_script("return window.pageYOffset")
-    print("page_index is %d window_page_y_offset is %d main_scroll_height is %d page_height is %d" % (page_index, window_page_y_offset, main_scroll_height, page_height))
-    
-    while ((window_page_y_offset + page_height < main_scroll_height) and (page_index < 100)):
+    print(
+        "page_index is %d window_page_y_offset is %d main_scroll_height is %d page_height is %d"
+        % (page_index, window_page_y_offset, main_scroll_height, page_height)
+    )
+
+    while (window_page_y_offset + page_height < main_scroll_height) and (
+        page_index < 100
+    ):
         driver.execute_script("window.scrollBy(0, %d);" % page_height)
         page_index = page_index + 1
-        driver.save_screenshot(dir_snapshot + os.path.sep + ("page_%06d.png"%page_index))
+        driver.save_screenshot(
+            dir_snapshot + os.path.sep + ("page_%06d.png" % page_index)
+        )
         window_page_y_offset = driver.execute_script("return window.pageYOffset")
-        print("page_index is %d window_page_y_offset is %d main_scroll_height is %d page_height is %d" % (page_index, window_page_y_offset, main_scroll_height, page_height))
-    assert(page_index < 100)
+        print(
+            "page_index is %d window_page_y_offset is %d main_scroll_height is %d page_height is %d"
+            % (page_index, window_page_y_offset, main_scroll_height, page_height)
+        )
+    assert page_index < 100
     driver.save_screenshot(dir_snapshot + os.path.sep + "screenshot_last_page.png")
     driver.close()
     return page_index
